@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 # URL test patterns for django-cookieless. Use this file to ensure a consistent
 # set of URL patterns are used when running unit tests. This test_urls
